@@ -69,7 +69,7 @@ def save_datasets(
     variables: Dict[str, Any],
     resultMap: Dict[str, Any],
     key: str,
-    values: List[BytesIO],
+    values: List[Any],
     file_names: Optional[List[str]] = None,
 ) -> None:
     """
@@ -124,7 +124,7 @@ def save_dataset(
     variables: Dict[str, Any],
     resultMap: Dict[str, Any],
     key: str,
-    value: BytesIO
+    value: Any
 ) -> None:
     """
     Save a single dataset.
@@ -145,11 +145,6 @@ def save_dataset(
     if value is None:
         raise ValidationError("value parameter cannot be None")
 
-    if not isinstance(value, BytesIO):
-        raise ValidationError(
-            f"value must be a BytesIO object, got {type(value).__name__}"
-        )
-
     if DATASET_MANAGEMENT == "LOCAL":
         return save_dataset_local(variables, resultMap, key, value)
 
@@ -167,13 +162,12 @@ def save_dataset_local(
     variables: Dict[str, Any],
     resultMap: Dict[str, Any],
     key: str,
-    value: BytesIO
+    value: Any
 ) -> None:
     """Save dataset locally using ProActive."""
 
     # Validate required keys
-    validate_variables_has_key(variables, "PA_JOB_ID", "variables")
-    validate_variables_has_key(variables, "PA_TASK_ID", "variables")
+    validate_variables_has_key(variables, "task_name", "variables")
 
     if key in variables:
         output_file_path = variables.get(key)
@@ -183,14 +177,17 @@ def save_dataset_local(
             outfile.write(value)
         print(f"Saved external output data to {output_file_path}")
     else:
-        job_id = variables.get("PA_JOB_ID")
-        task_id = variables.get("PA_TASK_ID")
-        task_folder = os.path.join("/shared", job_id, task_id)
+        # job_id = variables.get("PA_JOB_ID")
+        # task_id = variables.get("PA_TASK_ID")
+        # task_folder = os.path.join("/shared", job_id, task_id)
+        workflow_id = exp_engine_metadata["wf_id"]
+        task_name = variables.get("task_name")
+        task_folder = os.path.join("/shared", workflow_id, task_name)
         os.makedirs(task_folder, exist_ok=True)
         output_file_path = os.path.join(task_folder, key)
         with open(output_file_path, "wb") as outfile:
             pickle.dump(value, outfile)
-        variables.put("PREVIOUS_TASK_ID", str(task_id))
+        # variables.put("PREVIOUS_TASK_ID", str(task_id))
         print(f"Saved intermediate output data to {output_file_path}")
 
     if resultMap is not None:
@@ -202,7 +199,7 @@ def save_datasets_ddm(
     variables: Dict[str, Any],
     resultMap: Dict[str, Any],
     key: str,
-    values: List[bytes],
+    values: List[Any],
     file_names: Optional[List[str]] = None
 ) -> None:
     """Save multiple datasets to DDM using ProActive."""
@@ -288,7 +285,7 @@ def load_datasets(
     variables: Dict[str, Any],
     resultMap: Dict[str, Any],
     key: str
-) -> List[BytesIO]:
+) -> List[Any]:
     """
     Load multiple datasets (requires DDM).
 
@@ -298,7 +295,7 @@ def load_datasets(
         key: Dataset key to load
 
     Returns:
-        List[BytesIO]: List of loaded datasets
+        List[Any]: List of loaded datasets
 
     Raises:
         ValidationError: If inputs are invalid
@@ -322,7 +319,7 @@ def load_dataset(
     variables: Dict[str, Any],
     resultMap: Dict[str, Any],
     key: str
-) -> BytesIO:
+) -> Any:
     """
     Load a single dataset.
 
@@ -332,7 +329,7 @@ def load_dataset(
         key: Dataset key to load
 
     Returns:
-        BytesIO: The loaded dataset
+        Any: The loaded dataset
 
     Raises:
         ValidationError: If inputs are invalid
@@ -355,7 +352,7 @@ def load_dataset(
     raise ConfigurationError(error_msg)
 
 
-def load_dataset_local(variables: Dict[str, Any], key: str) -> BytesIO:
+def load_dataset_local(variables: Dict[str, Any], key: str) -> Any:
     """Load dataset from local storage using ProActive."""
     print(f"Loading input data with key '{key}'")
 
@@ -365,6 +362,7 @@ def load_dataset_local(variables: Dict[str, Any], key: str) -> BytesIO:
 
     if key in variables:
         input_filename = variables.get(key)
+        print(f"Loading external input data from {input_filename}")
         return load_dataset_by_path(input_filename)
     else:
         job_id = variables.get("PA_JOB_ID")
@@ -375,6 +373,7 @@ def load_dataset_local(variables: Dict[str, Any], key: str) -> BytesIO:
             if key in execution_engine_mapping[task_name]:
                 key = execution_engine_mapping[task_name][key]
         input_filename = os.path.join(task_folder, key)
+        print(f"Loading intermediate input data from {input_filename}")
         return load_pickled_dataset_by_path(input_filename)
 
 
@@ -563,8 +562,8 @@ def load_dataset_by_path(file_path: str) -> bytes:
         raise ValidationError(f"file_path must be a string, got {type(file_path).__name__}")
 
     with open(file_path, "rb") as f:
-        file_contents = BytesIO(f.read())
-    return file_contents.getvalue()
+        file_contents = f.read()
+    return file_contents
 
 
 def create_dir(variables: Dict[str, Any], key: str) -> str:
